package com.bonus.canteen.core.cook.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.canteen.core.cook.domain.CookDishesMaterial;
import com.bonus.canteen.core.cook.service.ICookDishesMaterialService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 菜品原料关联Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "菜品原料关联接口")
@RestController
@RequestMapping("/cook_dishes_material")
public class CookDishesMaterialController extends BaseController {
    @Autowired
    private ICookDishesMaterialService cookDishesMaterialService;

    /**
     * 查询菜品原料关联列表
     */
    @ApiOperation(value = "查询菜品原料关联列表")
    //@RequiresPermissions("cook:material:list")
    @GetMapping("/list")
    public TableDataInfo list(CookDishesMaterial cookDishesMaterial) {
        startPage();
        List<CookDishesMaterial> list = cookDishesMaterialService.selectCookDishesMaterialList(cookDishesMaterial);
        return getDataTable(list);
    }

    /**
     * 导出菜品原料关联列表
     */
    @ApiOperation(value = "导出菜品原料关联列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:material:export")
    @SysLog(title = "菜品原料关联", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出菜品原料关联")
    @PostMapping("/export")
    public void export(HttpServletResponse response, CookDishesMaterial cookDishesMaterial) {
        List<CookDishesMaterial> list = cookDishesMaterialService.selectCookDishesMaterialList(cookDishesMaterial);
        ExcelUtil<CookDishesMaterial> util = new ExcelUtil<CookDishesMaterial>(CookDishesMaterial.class);
        util.exportExcel(response, list, "菜品原料关联数据");
    }

    /**
     * 获取菜品原料关联详细信息
     */
    @ApiOperation(value = "获取菜品原料关联详细信息")
    //@RequiresPermissions("cook:material:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(cookDishesMaterialService.selectCookDishesMaterialById(id));
    }

    /**
     * 新增菜品原料关联
     */
    @ApiOperation(value = "新增菜品原料关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:material:add")
    @SysLog(title = "菜品原料关联", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增菜品原料关联")
    @PostMapping
    public AjaxResult add(@RequestBody CookDishesMaterial cookDishesMaterial) {
        try {
            return toAjax(cookDishesMaterialService.insertCookDishesMaterial(cookDishesMaterial));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改菜品原料关联
     */
    @ApiOperation(value = "修改菜品原料关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:material:edit")
    @SysLog(title = "菜品原料关联", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改菜品原料关联")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody CookDishesMaterial cookDishesMaterial) {
        try {
            return toAjax(cookDishesMaterialService.updateCookDishesMaterial(cookDishesMaterial));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除菜品原料关联
     */
    @ApiOperation(value = "删除菜品原料关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:material:remove")
    @SysLog(title = "菜品原料关联", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除菜品原料关联")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(cookDishesMaterialService.deleteCookDishesMaterialByIds(ids));
    }
}
